//----------------------------------------------------------------------------------
//
// 
// 
// (c) 2019 Jan Uhrin, OM2JU
//
//
$fn = 32;    // Rounding parameter; for production set to high (e.g. 40) 
//
//----------------------------------------------------------------------------------
//
// Rounded primitives for openscad
// (c) 2013 Wouter Robers 

// Syntax example for a rounded block
//translate([-15,0,10]) rcube([20,20,20],2);

// Syntax example for a rounded cylinder
//translate([15,0,10]) rcylinder(r1=15,r2=10,h=20,b=2);

module rcube(Size=[20,20,20],b=2)
{hull(){for(x=[-(Size[0]/2-b),(Size[0]/2-b)]){for(y=[-(Size[1]/2-b),(Size[1]/2-b)]){for(z=[-(Size[2]/2-b),(Size[2]/2-b)]){ translate([x,y,z]) sphere(b);}}}}}


module rcylinder(r1=10,r2=10,h=10,b=2)
{translate([0,0,-h/2]) hull(){rotate_extrude() translate([r1-b,b,0]) circle(r = b); rotate_extrude() translate([r2-b, h-b, 0]) circle(r = b);}}
    
//----------------------------------------------------------------------------------



difference() {
// difference of two rounded cubes, creates shell like object
translate([0,0,50/2])   rcube(Size=[20+120+1.6,70+3,50],b=4);
translate([0,0,60/2+2]) rcube(Size=[20+120-1.6,70,60],b=4);  

// big cube from top to limit height
translate([0,0,70+45]) cube(size=[180,180,140],center=true);  

// display opening
translate([14.5+37/2,50,30/2+8])   rcube(Size=[36.0,80,24.4],b=1);
translate([15.0-37/2,50,30/2+8])   rcube(Size=[36.0,80,24.4],b=1);
//translate([15,50,30/2+12])   rcube(Size=[72.0,80,24.4],b=2);

// hole for encoder ALPS EC11B15244A7
rotate([90,0,0]) translate([-44,23,-50])  cylinder(r1=6.8/2,r2=6.8/2,h=40,center=true);  


// Rear side holes
// USB Mini
translate([-52.5,-25,6]) cube(size=[16,40,8],center=true);  

// Rotator control - DIN Socket
// https://www.tme.eu/sk/details/dc-112/konektory-din/
rotate([90,0,0]) translate([-24,18,25])      cylinder(r1=15/2,r2=15/2,h=30,center=true);  
rotate([90,0,0]) translate([-24+22/2,18,25]) cylinder(r1=2.8/2,r2=2.8/2,h=30,center=true);  
rotate([90,0,0]) translate([-24-22/2,18,25]) cylinder(r1=2.8/2,r2=2.8/2,h=30,center=true);  

// 4x 3.5mm jacks
$jd = 6.2;
rotate([90,0,0]) translate([-2,18,25]) cylinder(r1=$jd/2,r2=$jd/2,h=30,center=true);  
rotate([90,0,0]) translate([9,18,25])  cylinder(r1=$jd/2,r2=$jd/2,h=30,center=true);  
rotate([90,0,0]) translate([20,18,25]) cylinder(r1=$jd/2,r2=$jd/2,h=30,center=true);  
rotate([90,0,0]) translate([31,18,25]) cylinder(r1=$jd/2,r2=$jd/2,h=30,center=true);  

// Rocker switch - SCI R13-66G-02-BB-5D   - opening 19 x 13.5
translate([52,-40,29]) cube(size=[19,20,13.5],center=true); 

// DC Jack
rotate([90,0,0]) translate([56,12,25])  cylinder(r1=8/2,r2=8/2,h=30,center=true);  


// Holes from left/right side for screws with conical heads
rotate([0,90,0]) translate([-40,0,0])   cylinder(r1=3.2/2,r2=3.2/2,h=150,center=true);  
rotate([0,90,0]) translate([-40,0,74])  cylinder(r1=1/2,r2=40/2,h=10,center=true);  
rotate([0,90,0]) translate([-40,0,-74]) cylinder(r1=40/2,r2=1/2,h=10,center=true);  

}

// Encoder
difference () {
//
translate([-44,33,23]) cube(size=[12,6,12],center=true); 
// hole for encoder
rotate([90,0,0]) translate([-44,23,-50])  cylinder(r1=6.8/2,r2=6.8/2,h=50,center=true);  
// hole to fix encoder from top using M3 screw
rotate([0,0,0]) translate([-44,32,45])  cylinder(r1=3.0/2,r2=3.0/2,h=40,center=true); 

}

translate([15+75/2,33.5,30/2+8 - 30.5/2]) M3displaypost();
translate([15-75/2,33.5,30/2+8 - 30.5/2]) M3displaypost();
translate([15+75/2,33.5,30/2+8 + 30.5/2]) M3displaypost();
translate([15-75/2,33.5,30/2+8 + 30.5/2]) M3displaypost();


// 75 x 30.5
module M3displaypost () {
difference () {
rotate([90,0,0]) translate([0,0,0])  cylinder(r1=6/2,r2=6/2,h=4,center=true);  
rotate([90,0,0]) translate([0,0,0])  cylinder(r1=3/2,r2=3/2,h=5,center=true);  
}
}


// 44mm
translate([-53,44-34+1,3.5]) rcube(Size=[30,4,6],b=1); 

